*********
ChangeLog
*********

|   20200907	v0.5.8	 Fixed a regex warning in utils.buildregex()
|   20200904	v0.5.7	 Added get_option_ids helper method.
|   20200821	v0.5.5	 Changes to project_urls for packaging
|   20200821	v0.5.4	 Fixed fact that documentation wasn't included in package.
|   20200818    v0.5.3   Streamlined get_id using _filter
|   20200818    v0.5.1   Initial Classes for Threat Defence DFP
|   20200818    v0.5.0   Initial Classes for Threat Defence (EP, Cloud, LAD)
|   20200817    v0.4.1   Added tag manipulation to b1ddi
|   20200810    v0.4.0   Minor changes and improved documentatin
|   20200810    v0.3.9   Fixed bug in b1td.get method
|   20200807    v0.3.8   Created b1td class for TIDE API b1td.py
|   20200714    v0.3.0   Added specific add/delete tags for on_prem_hosts
|   20200714    v0.2.4   Added create and update methods to b1platform class
|   20200713    v0.2.1   Renamed patch to update as originally intended 
|   20200713    v0.2.0   Removed original methods for get_object
|   20200713    v0.1.5   Added get_object_by_key and create initial documentation
|   20200711    v0.1.2   Added generic wrappers for DDI for create and delete
|                        Added get_id method to get object id from key/value pair
|   20200710    v0.1.1   Generic Wrapper and restructuring 
|   20200708    v0.0.5   Read only examples for several b1 objects
|		                  Commit before restructuring to a more generic
|                        wrappers and useful functions
|   20200701    v0.0.2   Subclass for b1ddi api methods added to b1
|   20200629    v0.0.1   Initial Class commit for b1 class
|                        Base class attributes and ini file 
|                        handling.

